==> mypy-boto3-athena-1.13.20.0.tar.gz: mypy-boto3-athena-1.13.20.0/mypy_boto3_athena/__init__.py <==
"""
Main interface for athena service.

Usage::

    import boto3
    from mypy_boto3.athena import (
        AthenaClient,
        Client,
        GetQueryResultsPaginator,
        ListDataCatalogsPaginator,
        ListDatabasesPaginator,
        ListNamedQueriesPaginator,
        ListQueryExecutionsPaginator,
        ListTableMetadataPaginator,
        ListTagsForResourcePaginator,
        )

    session = boto3.Session()

    client: AthenaClient = boto3.client("athena")
    session_client: AthenaClient = session.client("athena")

    get_query_results_paginator: GetQueryResultsPaginator = client.get_paginator("get_query_results")
    list_data_catalogs_paginator: ListDataCatalogsPaginator = client.get_paginator("list_data_catalogs")
    list_databases_paginator: ListDatabasesPaginator = client.get_paginator("list_databases")
    list_named_queries_paginator: ListNamedQueriesPaginator = client.get_paginator("list_named_queries")
    list_query_executions_paginator: ListQueryExecutionsPaginator = client.get_paginator("list_query_executions")
    list_table_metadata_paginator: ListTableMetadataPaginator = client.get_paginator("list_table_metadata")
    list_tags_for_resource_paginator: ListTagsForResourcePaginator = client.get_paginator("list_tags_for_resource")
"""
from mypy_boto3_athena.client import AthenaClient, AthenaClient as Client
from mypy_boto3_athena.paginator import (
    GetQueryResultsPaginator,
    ListDataCatalogsPaginator,
    ListDatabasesPaginator,
    ListNamedQueriesPaginator,
    ListQueryExecutionsPaginator,
    ListTableMetadataPaginator,
    ListTagsForResourcePaginator,
)


__all__ = (
    "AthenaClient",
    "Client",
    "GetQueryResultsPaginator",
    "ListDataCatalogsPaginator",
    "ListDatabasesPaginator",
    "ListNamedQueriesPaginator",
    "ListQueryExecutionsPaginator",
    "ListTableMetadataPaginator",
    "ListTagsForResourcePaginator",
)

==> mypy-boto3-athena-1.13.22.0.tar.gz: mypy-boto3-athena-1.13.22.0/mypy_boto3_athena/__init__.py <==
"""
Main interface for athena service.

Usage::

    import boto3
    from mypy_boto3.athena import (
        AthenaClient,
        Client,
        GetQueryResultsPaginator,
        ListDataCatalogsPaginator,
        ListDatabasesPaginator,
        ListNamedQueriesPaginator,
        ListQueryExecutionsPaginator,
        ListTableMetadataPaginator,
        ListTagsForResourcePaginator,
        )

    session = boto3.Session()

    client: AthenaClient = boto3.client("athena")
    session_client: AthenaClient = session.client("athena")

    get_query_results_paginator: GetQueryResultsPaginator = client.get_paginator("get_query_results")
    list_data_catalogs_paginator: ListDataCatalogsPaginator = client.get_paginator("list_data_catalogs")
    list_databases_paginator: ListDatabasesPaginator = client.get_paginator("list_databases")
    list_named_queries_paginator: ListNamedQueriesPaginator = client.get_paginator("list_named_queries")
    list_query_executions_paginator: ListQueryExecutionsPaginator = client.get_paginator("list_query_executions")
    list_table_metadata_paginator: ListTableMetadataPaginator = client.get_paginator("list_table_metadata")
    list_tags_for_resource_paginator: ListTagsForResourcePaginator = client.get_paginator("list_tags_for_resource")
"""
from mypy_boto3_athena.client import AthenaClient as Client, AthenaClient
from mypy_boto3_athena.paginator import (
    GetQueryResultsPaginator,
    ListDataCatalogsPaginator,
    ListDatabasesPaginator,
    ListNamedQueriesPaginator,
    ListQueryExecutionsPaginator,
    ListTableMetadataPaginator,
    ListTagsForResourcePaginator,
)


__all__ = (
    "AthenaClient",
    "Client",
    "GetQueryResultsPaginator",
    "ListDataCatalogsPaginator",
    "ListDatabasesPaginator",
    "ListNamedQueriesPaginator",
    "ListQueryExecutionsPaginator",
    "ListTableMetadataPaginator",
    "ListTagsForResourcePaginator",
)
